@@ -5,7 +5,9 @@ import os
 # by importing them here in conftest.py they are discoverable by py.test
 # no matter how it is invoked within the source tree.
 
-from astropy.tests.pytest_plugins import *
+from astropy.tests.pytest_plugins import (PYTEST_HEADER_MODULES,
+                                          enable_deprecations_as_exceptions,
+                                          TESTED_VERSIONS)
 
 try:
     packagename = os.path.basename(os.path.dirname(__file__))
