@@ -17,6 +17,7 @@ import os
 import re
 import keyring
 import threading
+import requests
 
 import numpy as np
 
@@ -26,6 +27,7 @@ from base64 import b64encode
 
 import astropy.units as u
 import astropy.coordinates as coord
+from astropy.utils import deprecated
 
 from astropy.table import Table, Row, vstack, MaskedColumn
 from astropy.extern.six.moves.urllib.parse import quote as urlencode
@@ -41,6 +43,8 @@ from ..exceptions import (TimeoutError, InvalidQueryError, RemoteServiceError,
                           LoginError, ResolverError, MaxResultsWarning,
                           NoResultsWarning, InputWarning, AuthenticationWarning)
 from . import conf
+from . import fpl
+
 
 __all__ = ['Observations', 'ObservationsClass',
            'Mast', 'MastClass']
@@ -108,6 +112,9 @@ def _mashup_json_to_table(json_obj, col_config=None):
         if atype == "int":  # int arrays do not admit Non/nan vals
             atype = np.int64
             ignoreValue = -999 if (ignoreValue is None) else ignoreValue
+        if atype == "date":
+            atype = "str"
+            ignoreValue = "" if (ignoreValue is None) else ignoreValue
 
         # Make the column list (don't assign final type yet or there will be errors)
         colData = np.array([x.get(col, ignoreValue) for x in json_obj['data']], dtype=object)
@@ -141,24 +148,93 @@ class MastClass(QueryWithLogin):
         super(MastClass, self).__init__()
 
         self._MAST_REQUEST_URL = conf.server + "/api/v0/invoke"
-        self._MAST_DOWNLOAD_URL = conf.server + "/api/v0/download/file"
         self._COLUMNS_CONFIG_URL = conf.server + "/portal/Mashup/Mashup.asmx/columnsconfig"
 
-        # shibbolith urls
-        self._SP_TARGET = conf.server + "/api/v0/Mashup/Login/login.html"
-        self._IDP_ENDPOINT = conf.ssoserver + "/idp/profile/SAML2/SOAP/ECP"
-        self._SESSION_INFO_URL = conf.server + "/Shibboleth.sso/Session"
-
         self.TIMEOUT = conf.timeout
         self.PAGESIZE = conf.pagesize
 
         self._column_configs = dict()
         self._current_service = None
 
+        try:
+            self._auth_mode = self._get_auth_mode()
+        except (requests.exceptions.ConnectionError, IOError):
+            # this is fine, we're in test mode
+            self._auth_mode = 'SHIB-ECP'
+
+        if "SHIB-ECP" == self._auth_mode:
+            log.debug("Using Legacy Shibboleth login")
+            self._SESSION_INFO_URL = conf.server + "/Shibboleth.sso/Session"
+            self._SP_TARGET = conf.server + "/api/v0/Mashup/Login/login.html"
+            self._IDP_ENDPOINT = conf.ssoserver + "/idp/profile/SAML2/SOAP/ECP"
+            self._MAST_DOWNLOAD_URL = conf.server + "/api/v0/Download/file"
+        elif "MAST-AUTH" == self._auth_mode:
+            log.debug("Using Auth.MAST login")
+            self._SESSION_INFO_URL = conf.server + "/whoami"
+            self._MAST_DOWNLOAD_URL = conf.server + "/api/v0.1/Download/file"
+            self._MAST_BUNDLE_URL = conf.server + "/api/v0.1/Download/bundle"
+        else:
+            raise Exception("Unknown MAST Auth mode %s" % self._auth_mode)
+
         if username or session_token:
             self.login(username, password, session_token)
 
-    def _attach_cookie(self, session_token):  # pragma: no cover
+    def _get_auth_mode(self):
+        _auth_mode = "SHIB-ECP"
+
+        # Detect auth mode from auth_type endpoint
+        resp = self._session.get(conf.server + '/auth_type')
+        if resp.status_code == 200:
+            _auth_mode = resp.text.strip()
+        else:
+            log.warning("Unknown MAST auth mode, defaulting to Legacy Shibboleth login")
+        return _auth_mode
+
+    def _login(self, *args, **kwargs):
+        if "SHIB-ECP" == self._auth_mode:
+            return self._shib_legacy_login(*args, **kwargs)
+        elif "MAST-AUTH" == self._auth_mode:
+            return self._authorize(*args, **kwargs)
+        else:
+            raise Exception("Unknown MAST Auth mode %s" % self._auth_mode)
+
+    def get_token(self, *args, **kwargs):
+        """
+        Returns MAST token cookie.
+
+        Returns
+        -------
+        response : `~http.cookiejar.Cookie`
+        """
+        if "SHIB-ECP" == self._auth_mode:
+            return self._shib_get_token(*args, **kwargs)
+        elif "MAST-AUTH" == self._auth_mode:
+            return self._get_token(*args, **kwargs)
+        else:
+            raise Exception("Unknown MAST Auth mode %s" % self._auth_mode)
+
+    def session_info(self, *args, **kwargs):  # pragma: no cover
+        """
+        Displays information about current MAST user, and returns user info dictionary.
+
+        Parameters
+        ----------
+        silent : bool, optional
+            Default False.
+            Suppresses output to stdout.
+
+        Returns
+        -------
+        response : dict
+        """
+        if "SHIB-ECP" == self._auth_mode:
+            return self._shib_session_info(*args, **kwargs)
+        elif "MAST-AUTH" == self._auth_mode:
+            return self._session_info(*args, **kwargs)
+        else:
+            raise Exception("Unknown MAST Auth mode %s" % self._auth_mode)
+
+    def _shib_attach_cookie(self, session_token):  # pragma: no cover
         """
         Attaches a valid shibboleth session cookie to the current session.
 
@@ -416,6 +492,27 @@ class MastClass(QueryWithLogin):
 
         self._column_configs[service] = response[0].json()
 
+        more = False  # for some catalogs this is not enough information
+        if "tess" in fetch_name.lower():
+            all_name = "Mast.Catalogs.All.Tic"
+            more = True
+        elif "dd." in fetch_name.lower():
+            all_name = "Mast.Catalogs.All.DiskDetective"
+            more = True
+
+        if more:
+            mashupRequest = {'service': all_name, 'params': {}, 'format': 'extjs'}
+            reqString = _prepare_service_request_string(mashupRequest)
+            response = self._request("POST", self._MAST_REQUEST_URL, data=reqString, headers=headers)
+            jsonResponse = response[0].json()
+
+            self._column_configs[service].update(jsonResponse['data']['Tables'][0]
+                                                 ['ExtendedProperties']['discreteHistogram'])
+            self._column_configs[service].update(jsonResponse['data']['Tables'][0]
+                                                 ['ExtendedProperties']['continuousHistogram'])
+            for col, val in self._column_configs[service].items():
+                val.pop('hist', None)  # don't want to save all this unecessary data
+
     def _parse_result(self, responses, verbose=False):
         """
         Parse the results of a list of ``requests.Response`` objects and returns an `astropy.table.Table` of results.
@@ -459,8 +556,53 @@ class MastClass(QueryWithLogin):
             warnings.warn("Query returned no results.", NoResultsWarning)
         return allResults
 
-    def _login(self, username=None, password=None, session_token=None,
-               store_password=False, reenter_password=False):  # pragma: no cover
+    def _authorize(self, token=None, store_token=False, reenter_token=False):  # pragma: no cover
+        """
+        Log into the MAST portal.
+
+        Parameters
+        ----------
+        token : string, optional
+            Default is None.
+            The token to authenticate the user.
+            This can be generated at
+                https://auth.mast.stsci.edu/token?suggested_name=Astroquery&suggested_scope=mast:exclusive_access.
+            If not supplied, it will be prompted for if not in the keyring or set via $MAST_API_TOKEN
+        store_token : bool, optional
+            Default False.
+            If true, username and password will be stored securely in your keyring.
+        """
+
+        if token is None and "MAST_API_TOKEN" in os.environ:
+            token = os.environ["MAST_API_TOKEN"]
+
+        if token is None:
+            token = keyring.get_password("astroquery:mast.stsci.edu.token", "masttoken")
+
+        if token is None or reenter_token:
+            auth_server = conf.server.replace("mast", "auth.mast")
+            auth_link = auth_server + "/token?suggested_name=Astroquery&suggested_scope=mast:exclusive_access"
+            info_msg = "If you do not have an API token already, visit the following link to create one: "
+            log.info(info_msg + auth_link)
+            token = getpass("Enter MAST API Token: ")
+
+        # store password if desired
+        if store_token:
+            keyring.set_password("astroquery:mast.stsci.edu.token", "masttoken", token)
+
+        self._session.headers["Accept"] = "application/json"
+        self._session.cookies["mast_token"] = token
+        info = self.session_info(silent=True)
+
+        if not info["anon"]:
+            log.info("MAST API token accepted, welcome %s" % info["attrib"].get("display_name"))
+        else:
+            log.warn("MAST API token invalid!")
+
+        return not info["anon"]
+
+    def _shib_legacy_login(self, username=None, password=None, session_token=None,
+                           store_password=False, reenter_password=False):  # pragma: no cover
         """
         Log into the MAST portal.
 
@@ -500,7 +642,7 @@ class MastClass(QueryWithLogin):
                           InputWarning)
 
         if session_token:
-            return self._attach_cookie(session_token)
+            return self._shib_attach_cookie(session_token)
         else:
             # get username if not supplied
             if not username:
@@ -520,40 +662,6 @@ class MastClass(QueryWithLogin):
 
             return self._shib_login(username, password)
 
-    def login(self, username=None, password=None, session_token=None,
-              store_password=False, reenter_password=False):  # pragma: no cover
-        """
-        Log into the MAST portal.
-
-        Parameters
-        ----------
-        username : string, optional
-            Default is None.
-            The username for the user logging in.
-            Usually this will be the user's email address.
-            If a username is necessary but not supplied it will be prompted for.
-        password : string, optional
-            Default is None.
-            The password associated with the given username.
-            For security passwords should not be typed into the terminal or jupyter
-            notebook, but input using a more secure method such as `~getpass.getpass`.
-            If a password is necessary but not supplied it will be prompted for.
-        session_token : dict or `~http.cookiejar.Cookie`, optional
-            A valid MAST session cookie that will be attached to the current session
-            in lieu of logging in with a username/password.
-            If username and/or password is supplied, this argument will be ignored.
-        store_password : bool, optional
-            Default False.
-            If true, username and password will be stored securely in your keyring.
-        reenter_password : bool, optional
-            Default False.
-            Asks for the password even if it is already stored in the keyring.
-            This is the way to overwrite an already stored password on the keyring.
-        """
-
-        return super(MastClass, self).login(username=username, password=password, session_token=session_token,
-                                            store_password=store_password, reenter_password=reenter_password)
-
     def logout(self):  # pragma: no cover
         """
         Log out of current MAST session.
@@ -561,7 +669,58 @@ class MastClass(QueryWithLogin):
         self._session.cookies.clear_session_cookies()
         self._authenticated = False
 
-    def get_token(self):  # pragma: no cover
+    def _get_token(self):  # pragma: no cover
+        """
+        Returns MAST token cookie.
+
+        Returns
+        -------
+        response : `~http.cookiejar.Cookie`
+        """
+
+        tokenCookie = None
+        for cookie in self._session.cookies:
+            if "mast_token" in cookie.name:
+                tokenCookie = cookie
+                break
+
+        if not tokenCookie:
+            warnings.warn("No auth token found.", AuthenticationWarning)
+
+        return tokenCookie
+
+    def _session_info(self, silent=False):  # pragma: no cover
+        """
+        Displays information about current MAST user, and returns user info dictionary.
+
+        Parameters
+        ----------
+        silent : bool, optional
+            Default False.
+            Suppresses output to stdout.
+
+        Returns
+        -------
+        response : dict
+        """
+
+        # get user information
+        self._session.headers["Accept"] = "application/json"
+        response = self._session.request("GET", self._SESSION_INFO_URL)
+
+        infoDict = json.loads(response.text)
+
+        if not silent:
+            for key, value in infoDict.items():
+                if isinstance(value, dict):
+                    for subkey, subval in value.items():
+                        print("%s.%s: %s" % (key, subkey, subval))
+                else:
+                    print("%s: %s" % (key, value))
+
+        return infoDict
+
+    def _shib_get_token(self):  # pragma: no cover
         """
         Returns MAST session cookie.
 
@@ -581,7 +740,7 @@ class MastClass(QueryWithLogin):
 
         return shibCookie
 
-    def session_info(self, silent=False):
+    def _shib_session_info(self, silent=False):  # pragma: no cover
         """
         Displays information about current MAST session, and returns session info dictionary.
 
@@ -653,7 +812,8 @@ class MastClass(QueryWithLogin):
 
         # setting self._current_service
         if service not in self._column_configs.keys():
-            self._get_col_config(service)
+            fetch_name = kwargs.pop('fetch_name', None)
+            self._get_col_config(service, fetch_name)
         self._current_service = service
 
         # setting up pagination
@@ -757,7 +917,8 @@ class MastClass(QueryWithLogin):
                 continue
 
             colType = "discrete"
-            if (colInfo.get("vot.datatype", colInfo.get("type")) in ("double", "float")) or colInfo.get("treatNumeric"):
+            if (colInfo.get("vot.datatype", colInfo.get("type")) in ("double", "float", "numeric")) \
+               or colInfo.get("treatNumeric"):
                 colType = "continuous"
 
             separator = colInfo.get("separator")
@@ -824,6 +985,7 @@ class ObservationsClass(MastClass):
 
         self._boto3 = None
         self._botocore = None
+        self._pubdata_bucket = "stpubdata"
 
     def list_missions(self):
         """
@@ -835,10 +997,10 @@ class ObservationsClass(MastClass):
             List of available missions.
         """
 
-        # getting all the hitogram information
+        # getting all the histogram information
         service = "Mast.Caom.All"
         params = {}
-        response = Mast.service_request_async(service, params, format='extjs')
+        response = self.service_request_async(service, params, format='extjs')
         jsonResponse = response[0].json()
 
         # getting the list of missions
@@ -1193,7 +1355,7 @@ class ObservationsClass(MastClass):
 
         return self.service_request_async(service, params)
 
-    def filter_products(self, products, mrp_only=True, **filters):
+    def filter_products(self, products, mrp_only=False, extension=None, **filters):
         """
         Takes an `astropy.table.Table` of MAST observation data products and filters it based on given filters.
 
@@ -1202,13 +1364,14 @@ class ObservationsClass(MastClass):
         products : `astropy.table.Table`
             Table containing data products to be filtered.
         mrp_only : bool, optional
-            Default True. When set to true only "Minimum Recommended Products" will be returned.
+            Default False. When set to true only "Minimum Recommended Products" will be returned.
+        extension : string, optional
+            Default None. Option to filter by file extension.
         **filters :
             Filters to be applied.  Valid filters are all products fields listed
-            `here <https://masttest.stsci.edu/api/v0/_productsfields.html>`__ and 'extension'
-            which is the desired file extension.
-            The Column Name (or 'extension') is the keyword, with the argument being one or
-            more acceptable values for that parameter.
+            `here <https://masttest.stsci.edu/api/v0/_productsfields.html>`__.
+            The column name is the keyword, with the argument being one or more acceptable values
+            for that parameter.
             Filter behavior is AND between the filters and OR within a filter set.
             For example: productType="SCIENCE",extension=["fits","jpg"]
 
@@ -1217,12 +1380,20 @@ class ObservationsClass(MastClass):
         response : `~astropy.table.Table`
         """
 
-        # Dealing with mrp first, b/c it's special
-        if mrp_only:
-            products.remove_rows(np.where(products['productGroupDescription'] != "Minimum Recommended Products"))
-
         filterMask = np.full(len(products), True, dtype=bool)
 
+        # Applying the special filters (mrp_only and extension)
+        if mrp_only:
+            filterMask &= (products['productGroupDescription'] == "Minimum Recommended Products")
+
+        if extension:
+            mask = np.full(len(products), False, dtype=bool)
+            for elt in extension:
+                mask |= [False if isinstance(x, np.ma.core.MaskedConstant) else x.endswith(elt)
+                         for x in products["productFilename"]]
+            filterMask &= mask
+
+        # Applying the rest of the filters
         for colname, vals in filters.items():
 
             if type(vals) == str:
@@ -1230,11 +1401,7 @@ class ObservationsClass(MastClass):
 
             mask = np.full(len(products), False, dtype=bool)
             for elt in vals:
-                if colname == 'extension':  # extension is not actually a column
-                    mask |= [False if isinstance(x, np.ma.core.MaskedConstant) else x.endswith(elt)
-                             for x in products["productFilename"]]
-                else:
-                    mask |= (products[colname] == elt)
+                mask |= (products[colname] == elt)
 
             filterMask &= mask
 
@@ -1256,11 +1423,45 @@ class ObservationsClass(MastClass):
         response : `astropy.table.Table`
         """
 
+        urlList = [("uri", url) for url in products['dataURI']]
+        downloadFile = "mastDownload_" + time.strftime("%Y%m%d%H%M%S")
+        localPath = os.path.join(out_dir.rstrip('/'), downloadFile + ".sh")
+
+        response = self._download_file(self._MAST_BUNDLE_URL + ".sh", localPath, data=urlList, method="POST")
+
+        status = "COMPLETE"
+        msg = None
+
+        if not os.path.isfile(localPath):
+            status = "ERROR"
+            msg = "Curl could not be downloaded"
+
+        manifest = Table({'Local Path': [localPath],
+                          'Status': [status],
+                          'Message': [msg]})
+        return manifest
+
+    def _shib_download_curl_script(self, products, out_dir):
+        """
+        Takes an `astropy.table.Table` of data products and downloads a curl script to pull the datafiles.
+
+        Parameters
+        ----------
+        products : `astropy.table.Table`
+            Table containing products to be included in the curl script.
+        out_dir : str
+            Directory in which the curl script will be saved.
+
+        Returns
+        -------
+        response : `astropy.table.Table`
+        """
+
         urlList = products['dataURI']
+        downloadFile = "mastDownload_" + time.strftime("%Y%m%d%H%M%S")
         descriptionList = products['description']
         productTypeList = products['dataproduct_type']
 
-        downloadFile = "mastDownload_" + time.strftime("%Y%m%d%H%M%S")
         pathList = [downloadFile+"/"+x['obs_collection']+'/'+x['obs_id']+'/'+x['productFilename'] for x in products]
 
         service = "Mast.Bundle.Request"
@@ -1299,88 +1500,92 @@ class ObservationsClass(MastClass):
                           "URL": [url]})
         return manifest
 
+    @deprecated(since="v0.3.9", alternative="enable_cloud_dataset")
     def enable_s3_hst_dataset(self):
+        return self.enable_cloud_dataset()
+
+    def enable_cloud_dataset(self, provider="AWS", profile=None):
         """
-        Attempts to enable downloading HST public files from S3 instead of MAST.
+        Attempts to enable downloading public files from S3 instead of MAST.
         Requires the boto3 library to function.
         """
         import boto3
         import botocore
-        self._boto3 = boto3
+        if profile is not None:
+            self._boto3 = boto3.Session(profile_name=profile)
+        else:
+            self._boto3 = boto3
         self._botocore = botocore
 
-        log.info("Using the S3 HST public dataset")
+        log.info("Using the S3 STScI public dataset")
         log.warning("Your AWS account will be charged for access to the S3 bucket")
         log.info("See Request Pricing in https://aws.amazon.com/s3/pricing/ for details")
-        log.info("If you have not configured boto3, follow the instructions here: " +
+        log.info("If you have not configured boto3, follow the instructions here: "
                  "https://boto3.readthedocs.io/en/latest/guide/configuration.html")
 
+    @deprecated(since="v0.3.9", alternative="disable_cloud_dataset")
     def disable_s3_hst_dataset(self):
+        return self.disable_cloud_dataset()
+
+    def disable_cloud_dataset(self):
         """
-        Disables downloading HST public files from S3 instead of MAST
+        Disables downloading public files from S3 instead of MAST
         """
         self._boto3 = None
         self._botocore = None
 
-    def _download_from_s3(self, dataProduct, localPath, cache=True):
+    @deprecated(since="v0.3.9", alternative="get_cloud_uris")
+    def get_hst_s3_uris(self, dataProducts, includeBucket=True, fullUrl=False):
+        return self.get_cloud_uris(dataProducts, includeBucket, fullUrl)
+
+    def get_cloud_uris(self, dataProducts, includeBucket=True, fullUrl=False):
+        """ Takes an `astropy.table.Table` of data products and turns them into s3 uris. """
+
+        return [self.get_cloud_uri(dataProduct, includeBucket, fullUrl) for dataProduct in dataProducts]
+
+    @deprecated(since="v0.3.9", alternative="get_cloud_uri")
+    def get_hst_s3_uri(self, dataProduct, includeBucket=True, fullUrl=False):
+        return self.get_cloud_uri(dataProduct, includeBucket, fullUrl)
+
+    def get_cloud_uri(self, dataProduct, includeBucket=True, fullUrl=False):
+        """ Turns a dataProduct into a S3 URI """
+
+        if self._boto3 is None:
+            raise AtrributeError("Must enable s3 dataset before attempting to query the s3 information")
+
+        # This is a cheap operation and does not perform any actual work yet
+        s3_client = self._boto3.client('s3')
+
+        paths = fpl.paths(dataProduct)
+        if paths is None:
+            raise Exception("Unsupported mission")
+
+        for path in paths:
+            try:
+                s3_client.head_object(Bucket=self._pubdata_bucket, Key=path, RequestPayer='requester')
+                if includeBucket:
+                    path = "s3://%s/%s" % (self._pubdata_bucket, path)
+                elif fullUrl:
+                    path = "http://s3.amazonaws.com/%s/%s" % (self._pubdata_bucket, path)
+                return path
+            except self._botocore.exceptions.ClientError as e:
+                if e.response['Error']['Code'] != "404":
+                    raise
+
+        raise Exception("Unable to locate file!")
+
+    def _download_from_cloud(self, dataProduct, localPath, cache=True):
         # The following is a mishmash of BaseQuery._download_file and s3 access through boto
 
-        bkt_name = 'stpubdata'
+        self._pubdata_bucket = 'stpubdata'
 
         # This is a cheap operation and does not perform any actual work yet
         s3 = self._boto3.resource('s3')
         s3_client = self._boto3.client('s3')
-        bkt = s3.Bucket(bkt_name)
+        bkt = s3.Bucket(self._pubdata_bucket)
 
-        dataUri = dataProduct['dataURI']
-        filename = dataUri.split("/")[-1]
-        obs_id = dataProduct['obs_id']
-
-        obs_id = obs_id.lower()
-
-        # This next part is a bit funky.  Let me explain why:
-        # We have 2 different possible URI schemes for HST:
-        #   mast:HST/product/obs_id_filename.type (old style)
-        #   mast:HST/product/obs_id/obs_id_filename.type (new style)
-        # The first scheme was developed thinking that the obs_id in the filename
-        # would *always* match the actual obs_id folder the file was placed in.
-        # Unfortunately this assumption was false.
-        # We have been trying to switch to the new uri scheme as it specifies the
-        # obs_id used in the folder path correctly.
-        # The cherry on top is that the obs_id in the new style URI is not always correct either!
-        # When we are looking up files we have some code which iterates through all of
-        # the possible permutations of the obs_id's last char which can be *ANYTHING*
-        #
-        # So in conclusion we can't trust the last char obs_id from the file or from the database
-        # So with that in mind, hold your nose when reading the following:
-
-        info_lookup = None
-        sane_path = os.path.join("hst", "public", obs_id[:4], obs_id, filename)
-        try:
-            info_lookup = s3_client.head_object(Bucket=bkt_name, Key=sane_path, RequestPayer='requester')
-            bucketPath = sane_path
-        except self._botocore.exceptions.ClientError as e:
-            if e.response['Error']['Code'] != "404":
-                raise
-
-        if info_lookup is None:
-            # Unfortunately our file placement logic is anything but sane
-            # We put files in folders that don't make sense
-            for ch in (string.digits + string.ascii_lowercase):
-                # The last char of the obs_folder (observation id) can be any lowercase or numeric char
-                insane_obs = obs_id[:-1] + ch
-                insane_path = os.path.join("hst", "public", insane_obs[:4], insane_obs, filename)
-
-                try:
-                    info_lookup = s3_client.head_object(Bucket=bkt_name, Key=insane_path, RequestPayer='requester')
-                    bucketPath = insane_path
-                    break
-                except self._botocore.exceptions.ClientError as e:
-                    if e.response['Error']['Code'] != "404":
-                        raise
-
-        if info_lookup is None:
-            raise Exception("Unable to locate file!")
+        bucketPath = self.get_cloud_uri(dataProduct, False)
+        info_lookup = s3_client.head_object(Bucket=self._pubdata_bucket, Key=bucketPath, RequestPayer='requester')
 
         # Unfortunately, we can't use the reported file size in the reported product.  STScI's backing
         # archive database (CAOM) is frequently out of date and in many cases omits the required information.
@@ -1403,7 +1608,7 @@ class ObservationsClass(MastClass):
                     return
 
         with ProgressBarOrSpinner(length, ('Downloading URL s3://{0}/{1} to {2} ...'.format(
-                bkt_name, bucketPath, localPath))) as pb:
+                self._pubdata_bucket, bucketPath, localPath))) as pb:
 
             # Bytes read tracks how much data has been received so far
             # This variable will be updated in multiple threads below
@@ -1459,15 +1664,15 @@ class ObservationsClass(MastClass):
             url = None
 
             try:
-                if self._boto3 is not None and dataProduct["dataURI"].startswith("mast:HST/product"):
+                if self._boto3 is not None and fpl.has_path(dataProduct):
                     try:
-                        self._download_from_s3(dataProduct, localPath, cache)
+                        self._download_from_cloud(dataProduct, localPath, cache)
                     except Exception as ex:
                         log.exception("Error pulling from S3 bucket: %s" % ex)
                         log.warn("Falling back to mast download...")
-                        self._download_file(dataUrl, localPath, cache=cache)
+                        self._download_file(dataUrl, localPath, cache=cache, head_safe=True)
                 else:
-                    self._download_file(dataUrl, localPath, cache=cache)
+                    self._download_file(dataUrl, localPath, cache=cache, head_safe=True)
 
                 # check if file exists also this is where would perform md5,
                 # and also check the filesize if the database reliably reported file sizes
@@ -1488,7 +1693,7 @@ class ObservationsClass(MastClass):
         return manifest
 
     def download_products(self, products, download_dir=None,
-                          cache=True, curl_flag=False, mrp_only=True, **filters):
+                          cache=True, curl_flag=False, mrp_only=False, **filters):
         """
         Download data products.
 
@@ -1506,7 +1711,7 @@ class ObservationsClass(MastClass):
             Default is False.  If true instead of downloading files directly, a curl script
             will be downloaded that can be used to download the data files at a later time.
         mrp_only : bool, optional
-            Default True. When set to true only "Minimum Recommended Products" will be returned.
+            Default False. When set to true only "Minimum Recommended Products" will be returned.
         **filters :
             Filters to be applied.  Valid filters are all products fields listed
             `here <https://masttest.stsci.edu/api/v0/_productsfields.html>`__ and 'extension'
@@ -1548,7 +1753,10 @@ class ObservationsClass(MastClass):
             download_dir = '.'
 
         if curl_flag:  # don't want to download the files now, just the curl script
-            manifest = self._download_curl_script(products, download_dir)
+            if "SHIB-ECP" == self._auth_mode:
+                manifest = self._shib_download_curl_script(products, download_dir)
+            else:
+                manifest = self._download_curl_script(products, download_dir)
 
         else:
             base_dir = download_dir.rstrip('/') + "/mastDownload"
@@ -1583,7 +1791,7 @@ class CatalogsClass(MastClass):
 
     @class_or_instance
     def query_region_async(self, coordinates, radius=0.2*u.deg, catalog="Hsc",
-                           pagesize=None, page=None, **kwargs):
+                           version=None, pagesize=None, page=None, **kwargs):
         """
         Given a sky position and radius, returns a list of catalog entries.
         See column documentation for specific catalogs `here <https://mast.stsci.edu/api/v0/pages.htmll>`__.
@@ -1601,6 +1809,8 @@ class CatalogsClass(MastClass):
         catalog : str, optional
             Default HSC.
             The catalog to be queried.
+        version : int, optional
+            Version number for catalogs that have versions. Default is highest version.
         pagesize : int, optional
             Default None.
             Can be used to override the default pagesize for (set in configs) this query only.
@@ -1610,7 +1820,7 @@ class CatalogsClass(MastClass):
             Can be used to override the default behavior of all results being returned to
             obtain a specific page of results.
         **kwargs
-            Catalog-specific keyword args.
+            Other catalog-specific keyword args.
             These can be found in the (service documentation)[https://mast.stsci.edu/api/v0/_services.html]
             for specific catalogs. For example one can specify the magtype for an HSC search.
 
@@ -1629,11 +1839,26 @@ class CatalogsClass(MastClass):
 
         # Figuring out the service
         if catalog.lower() == "hsc":
-            service = "Mast.Hsc.Db"
+            if version == 2:
+                service = "Mast.Hsc.Db.v2"
+            else:
+                if version not in (3, None):
+                    warnings.warn("Invalid HSC version number, defaulting to v3.", InputWarning)
+                service = "Mast.Hsc.Db.v3"
             self.catalogLimit = kwargs.get('nr', 50000)
+
         elif catalog.lower() == "galex":
             service = "Mast.Galex.Catalog"
             self.catalogLimit = kwargs.get('maxrecords', 50000)
+
+        elif catalog.lower() == "gaia":
+            if version == 1:
+                service = "Mast.Catalogs.GaiaDR1.Cone"
+            else:
+                if version not in (2, None):
+                    warnings.warn("Invalid Gaia version number, defaulting to DR2.", InputWarning)
+                service = "Mast.Catalogs.GaiaDR2.Cone"
+
         else:
             service = "Mast.Catalogs." + catalog + ".Cone"
             self.catalogLimit = None
@@ -1735,13 +1960,13 @@ class CatalogsClass(MastClass):
         radius = criteria.pop('radius', 0.2*u.deg)
 
         # Build the mashup filter object
-        if catalog == "Tic":
+        if catalog.lower() == "tic":
             service = "Mast.Catalogs.Filtered.Tic"
             if coordinates or objectname:
                 service += ".Position"
             mashupFilters = self._build_filter_set("Mast.Catalogs.Tess.Cone", service, **criteria)
 
-        elif catalog == "DiskDetective":
+        elif catalog.lower() == "diskdetective":
             service = "Mast.Catalogs.Filtered.DiskDetective"
             if coordinates or objectname:
                 service += ".Position"
@@ -1779,12 +2004,12 @@ class CatalogsClass(MastClass):
 
         # TIC needs columns specified
         if catalog == "Tic":
-            params["columns"] = "c.*"
+            params["columns"] = "*"
 
-        return self.service_request_async(service, params)
+        return self.service_request_async(service, params, pagesize=pagesize, page=page)
 
     @class_or_instance
-    def query_hsc_matchid_async(self, match, pagesize=None, page=None):
+    def query_hsc_matchid_async(self, match, version=3, pagesize=None, page=None):
         """
         Returns all the matches for a given Hubble Source Catalog MatchID.
 
@@ -1792,6 +2017,8 @@ class CatalogsClass(MastClass):
         ----------
         match : int or `~astropy.table.Row`
             The matchID or HSC entry to return matches for.
+        version : int, optional
+            The HSC version to match against. Default is v3.
         pagesize : int, optional
             Can be used to override the default pagesize.
             E.g. when using a slow internet connection.
@@ -1808,7 +2035,13 @@ class CatalogsClass(MastClass):
             match = match["MatchID"]
         match = str(match)  # np.int64 gives json serializer problems, so strigify right here
 
-        service = "Mast.HscMatches.Db"
+        if version == 2:
+            service = "Mast.HscMatches.Db.v2"
+        else:
+            if version not in (3, None):
+                warnings.warn("Invalid HSC version number, defaulting to v3.", InputWarning)
+            service = "Mast.HscMatches.Db.v3"
+
         params = {"input": match}
 
         return self.service_request_async(service, params, pagesize, page)
@@ -1877,12 +2110,12 @@ class CatalogsClass(MastClass):
             pathList = []
             for spec in spectra:
                 if spec['SpectrumType'] < 2:
-                    urlList.append('https://hla.stsci.edu/cgi-bin/getdata.cgi?config=ops&dataset=' +
-                                   spec['DatasetName'])
+                    urlList.append('https://hla.stsci.edu/cgi-bin/getdata.cgi?config=ops&dataset={0}'
+                                   .format(spec['DatasetName']))
 
                 else:
-                    urlList.append('https://hla.stsci.edu/cgi-bin/ecfproxy?file_id=' +
-                                   spec['DatasetName'] + '.fits')
+                    urlList.append('https://hla.stsci.edu/cgi-bin/ecfproxy?file_id={0}'
+                                   .format(spec['DatasetName']) + '.fits')
 
                 pathList.append(downloadFile + "/HSC/" + spec['DatasetName'] + '.fits')
 
@@ -1901,7 +2134,7 @@ class CatalogsClass(MastClass):
             bundlerResponse = response[0].json()
 
             localPath = download_dir.rstrip('/') + "/" + downloadFile + ".sh"
-            self._download_file(bundlerResponse['url'], localPath)
+            self._download_file(bundlerResponse['url'], localPath, head_safe=True)
 
             status = "COMPLETE"
             msg = None
@@ -1948,7 +2181,7 @@ class CatalogsClass(MastClass):
                 url = None
 
                 try:
-                    self._download_file(dataUrl, localPath, cache=cache)
+                    self._download_file(dataUrl, localPath, cache=cache, head_safe=True)
 
                     # check file size also this is where would perform md5
                     if not os.path.isfile(localPath):
