@@ -5,7 +5,6 @@ import re
 import os
 import warnings
 import functools
-import getpass
 import keyring
 
 import numpy as np
@@ -18,7 +17,7 @@ from astropy import log
 from bs4 import BeautifulSoup
 
 from ..query import QueryWithLogin
-from ..utils import commons, async_to_sync, system_tools, prepend_docstr_nosections
+from ..utils import commons, async_to_sync, prepend_docstr_nosections
 from ..exceptions import TableParseError, LoginError
 
 from . import conf
@@ -235,8 +234,8 @@ class NraoClass(QueryWithLogin):
             PASSWD="",  # TODO: implement login...
             SUBMIT="Submit Query")
 
-        if (request_payload['QUERYTYPE'] == "ARCHIVE" and
-            request_payload['PROTOCOL'] != 'HTML'):
+        if ((request_payload['QUERYTYPE'] == "ARCHIVE" and
+             request_payload['PROTOCOL'] != 'HTML')):
             warnings.warn("Changing protocol to HTML: ARCHIVE queries do not"
                           " support votable returns")
             request_payload['PROTOCOL'] = 'HTML'
@@ -277,7 +276,8 @@ class NraoClass(QueryWithLogin):
 
         # Developer notes:
         # Login via https://my.nrao.edu/cas/login
-        # # this can be added to auto-redirect back to the query tool: ?service=https://archive.nrao.edu/archive/advquery.jsp
+        # # this can be added to auto-redirect back to the query tool:
+        # ?service=https://archive.nrao.edu/archive/advquery.jsp
 
         if username is None:
             if not self.USERNAME:
@@ -295,20 +295,9 @@ class NraoClass(QueryWithLogin):
             return True
 
         # Get password from keyring or prompt
-        if reenter_password is False:
-            password_from_keyring = keyring.get_password(
-                "astroquery:my.nrao.edu", username)
-        else:
-            password_from_keyring = None
+        password, password_from_keyring = self._get_password(
+            "astroquery:my.nrao.edu", username, reenter=reenter_password)
 
-        if password_from_keyring is None:
-            if system_tools.in_ipynb():
-                log.warning("You may be using an ipython notebook:"
-                            " the password form will appear in your terminal.")
-            password = getpass.getpass("{0}, enter your NRAO archive password:"
-                                       "\n".format(username))
-        else:
-            password = password_from_keyring
         # Authenticate
         log.info("Authenticating {0} on my.nrao.edu ...".format(username))
         # Do not cache pieces of the login process
@@ -460,7 +449,7 @@ class NraoClass(QueryWithLogin):
                                   " and the error in self.table_parse_error.")
 
     def _parse_html_result(self, response, verbose=False):
-        # pares the HTML return...
+        # parse the HTML return...
         root = BeautifulSoup(response.content, 'html5lib')
 
         htmltable = root.findAll('table')
@@ -473,7 +462,7 @@ class NraoClass(QueryWithLogin):
         if six.PY2:
             from astropy.io.ascii import html
             from astropy.io.ascii.core import convert_numpy
-            htmlreader = html.HTML()
+            htmlreader = html.HTML({'parser': 'html5lib'})
             htmlreader.outputter.default_converters.append(convert_numpy(np.unicode))
             table = htmlreader.read(string_to_parse)
         else:
