@@ -11,7 +11,7 @@ class Conf(_config.ConfigNamespace):
     """
     # Config related to remote database of "reliable" services.
     vos_baseurl = _config.ConfigItem(
-        'http://stsdas.stsci.edu/astrolib/vo_databases/',
+        'https://astropy.stsci.edu/aux/vo_databases/',
         'URL where the VO Service database file is stored.')
     conesearch_dbname = _config.ConfigItem(
         'conesearch_good',
